# Архитектурная документация SuperDocs

Добро пожаловать в архитектурную документацию проекта SuperDocs! Здесь вы найдете подробную информацию о том, как устроен и работает расширенный MCP сервер для документации.

## 📚 Документы архитектуры

### 🏗️ Основные документы
- **[overview.md](overview.md)** - Полный обзор архитектуры SuperDocs с диаграммами и схемами
- **[tools_summary.md](tools_summary.md)** - Краткая сводка всех доступных MCP инструментов и их возможностей

### 🔧 Компоненты системы
- **[components/main.md](components/main.md)** - Ядро MCP сервера и бизнес-логика
- **[components/cli.md](components/cli.md)** - Интерфейс командной строки и конфигурация
- **[components/link_extractor.md](components/link_extractor.md)** - Модуль извлечения ссылок для навигации
- **[components/langgraph.md](components/langgraph.md)** - Специализированный сервер для LangGraph
- **[components/splash.md](components/splash.md)** - ASCII арт и визуальные элементы
- **[components/version.md](components/version.md)** - Управление версиями
- **[components/config.md](components/config.md)** - Конфигурация проекта и зависимости

## 🛠️ Быстрый старт для разработчиков

### Основные инструменты SuperDocs
1. **`list_doc_sources()`** - Получение списка источников документации
2. **`fetch_docs(url)`** - Загрузка и конвертация документов в Markdown
3. **`browse_page(url)`** ⭐ NEW - Навигация с извлечением ссылок

### Типичный workflow
```
list_doc_sources() → browse_page(index) → browse_page(section) → fetch_docs(document)
```

## 🔍 Что нового в v0.2.0

- ✅ **browse_page инструмент** - Интеллектуальная навигация по документации
- ✅ **link_extractor модуль** - Автоматическое извлечение ссылок из HTML/Markdown
- ✅ **Улучшенная безопасность** - Расширенная валидация URL и путей
- ✅ **Поддержка локальных файлов** - Работа с file:// протоколом

## 🎯 Ключевые принципы архитектуры

1. **Модульность** - Четкое разделение функциональности
2. **Безопасность** - Строгий контроль доступа к ресурсам  
3. **Простота** - Минимальный набор инструментов для максимальной эффективности
4. **Расширяемость** - Легкое добавление новых возможностей
5. **Совместимость** - Полная поддержка MCP протокола

## 🚀 Планы развития

### Приоритет 1 (Ближайшие релизы)
- **Кэширование** - In-memory кэш с TTL для ускорения работы
- **Поиск** - search_docs() для полнотекстового поиска по документации
- **Метрики** - Логирование и аналитика использования

### Приоритет 2 (Будущие версии) 
- **Новые форматы** - OpenAPI/Swagger, Notion, Confluence поддержка
- **Автообновление** - Периодическая синхронизация источников
- **AI-Enhanced** - Семантический поиск и автоматическое реферирование

## 🔗 Полезные ссылки

- [Основной README проекта](../../README.md)
- [Конфигурация разработки](../../pyproject.toml)
- [Примеры конфигурации](../../sample_config.yaml)
- [MCP Specification](https://spec.modelcontextprotocol.io/)

---

**Нужна помощь?** Изучите [tools_summary.md](tools_summary.md) для быстрого понимания возможностей или [overview.md](overview.md) для полного погружения в архитектуру. 