# 🛠️ Сводка инструментов SuperDocs

## Доступные MCP инструменты

### 1. `list_doc_sources()`
**Назначение:** Показывает все доступные источники документации  
**Параметры:** Нет  
**Использование:** Первый инструмент для начала работы с документацией  

### 2. `search_docs(source_url, query)`
**Назначение:** Умный поиск по документации с автоматическим fallback  
**Параметры:**
- `source_url` - URL источника документации (из list_doc_sources)
- `query` - поисковый запрос

**Логика работы:**
- Для DocParser источников (`docparser.agentium.ru`) - семантический поиск через API
- При недоступности поиска - автоматический fallback на `browse_page()`
- Для других источников - сразу использует навигацию

**Возвращает:** Результаты поиска с релевантностью или содержимое страниц

### 3. `browse_page(url)`
**Назначение:** Навигация по документации с извлечением ссылок  
**Параметры:** `url` - URL страницы для навигации  
**Возвращает:** Содержимое страницы + список всех найденных ссылок  

### 4. `fetch_docs(url)`
**Назначение:** Загружает и конвертирует документы в Markdown  
**Параметры:** `url` - URL документа или путь к локальному файлу  
**Возвращает:** Содержимое документа в формате Markdown  

## Рекомендуемый workflow

1. **`list_doc_sources()`** - получить доступные источники
2. **`search_docs(source_url, query)`** - найти релевантную документацию  
3. **`fetch_docs(url)`** - получить полное содержимое найденных документов
4. **`browse_page(url)`** - при необходимости навигации по структуре

## KISS принцип

Новый `search_docs` инструмент следует принципу KISS:
- 50 строк кода вместо сложных систем
- Простая логика: попробовать поиск → fallback
- Без кэширования, метрик, сложных retry
- Максимальная функциональность при минимальной сложности

## 🔄 Типичный workflow навигации

### Сценарий 1: Изучение новой документации
```
1. list_doc_sources() → получить список источников
2. browse_page(index_url) → посмотреть главную страницу и ссылки  
3. browse_page(section_url) → перейти в интересующий раздел
4. fetch_docs(specific_doc) → получить конкретный документ
```

### Сценарий 2: Поиск конкретной информации
```
1. list_doc_sources() → найти нужный источник
2. browse_page(index_url) → найти релевантные ссылки
3. fetch_docs(target_doc) → получить нужную информацию
```

### Сценарий 3: Исследование структуры документации
```
1. browse_page(root_url) → изучить корневую структуру
2. browse_page(category_url) → перейти в категорию  
3. browse_page(subcategory_url) → углубиться в подкатегорию
4. fetch_docs(final_doc) → прочитать финальный документ
```

---

## 🔐 Система безопасности

### Контроль доступа
- **HTTP домены**: Только разрешенные домены из конфигурации
- **Локальные файлы**: Только файлы из белого списка
- **Wildcard поддержка**: `'*'` разрешает все домены (для разработки)

### Валидация URL
- **Path traversal защита**: Предотвращение `../` атак
- **URL нормализация**: Безопасная обработка относительных путей
- **Protocol validation**: Поддержка http/https/file://

### Ограничения производительности
- **Таймауты**: 10 секунд на HTTP запрос
- **Size limits**: Разумные ограничения на размер контента
- **Redirect control**: Контроль HTTP редиректов

---

## 🎯 Возможности и ограничения

### ✅ Что работает отлично
- Базовая навигация по иерархической документации
- Безопасная загрузка локальных и удаленных файлов
- Автоматическое извлечение навигационных ссылок
- Конвертация HTML в читаемый Markdown
- Поддержка популярных AI IDE (Cursor, Windsurf, Claude)

### ⚠️ Текущие ограничения
- Нет кэширования (каждый запрос загружает заново)
- Отсутствует поиск по содержимому документов
- Нет автоматического обновления источников
- Отсутствуют метрики использования
- Нет поддержки streaming для больших документов

### 🔮 Планируемые улучшения
- **Кэширование**: In-memory кэш с TTL для ускорения
- **Поиск**: `search_docs()` для полнотекстового поиска  
- **Метрики**: Логирование и аналитика использования
- **Автообновление**: Периодическая синхронизация источников
- **Расширенная навигация**: Фильтрация ссылок по типу

---

## 📖 Примеры интеграции

### Cursor IDE
```json
{
  "mcpServers": {
    "superdocs": {
      "command": "uvx",
      "args": ["--from", "superdocs", "superdocs", "--yaml", "config.yaml"]
    }
  }
}
```

### Конфигурация YAML
```yaml
- name: LangGraph
  llms_txt: https://langchain-ai.github.io/langgraph/llms.txt
- name: LocalDocs  
  llms_txt: file:///path/to/docs.txt
```

### Использование в коде
```python
from superdocs.main import create_server

server = create_server([
    {"name": "LangGraph", "llms_txt": "https://langchain-ai.github.io/langgraph/llms.txt"}
])
```

---

## 🏗️ Архитектурные принципы

1. **Простота**: Минимальный набор инструментов для максимальной эффективности
2. **Безопасность**: Строгий контроль доступа к ресурсам
3. **Универсальность**: Работа с любыми llms.txt источниками
4. **Расширяемость**: Легкое добавление новых функций
5. **Производительность**: Оптимизация для быстрого доступа к документации 